==> tuia-public-tools-service-api-1.3.11-sources.jar: cn/tuia/tools/api/dto/advert/AdvertCallBackConstant.java <==
package cn.tuia.tools.api.dto.advert;

/**
 * @Description:
 * @author: 阿海
 * @create: 2020-06-28 17:40
 */
public class AdvertCallBackConstant {
    /**
     * 开关开启
     */
    public static String ON_FLAG = "1";

    /**
     * 宏替换开关，1为老版本，2为新版本，公共服务只有2才会处理
     */
    public static String MACRO_ON_FLAG_1 = "1";
    public static String MACRO_ON_FLAG_2 = "2";

    /**
     * 定制化处理--------------------------------------------------------------------------
     * 是否开启宏替换的开关
     */
    public static String MACRO_FLAG = "macro";

    /**
     * MD5签名处理，京东定制的需求
     * 参数上会拼接：&signMd5Flag=jingdong
     */
    public static String SIGN_MD5_FLAG = "signMd5Flag";

    /**
     * info日志开启的开关
     */
    public static String LOG_INFO_FLAG = "logInfoFlag";


    /**
     * 是否进行URL的decode开关
     * <p>
     * 【1】URLEncoder.encode(userAgent, "UTF-8")
     * ,ua.replaceAll("\\+","%20"))
     * <p>
     * 【2】大众点评：commonRestTemolate.getForObject(builder.build(true).toUri(), String.class);
     */
    public static String IS_ENCODE = "isEncode";

    /**
     * 宏替换的分隔符
     */
    public static String MACRO_SPLIT = "__";


    /**
     * 定制化处理宏替换--------------------------------------------
     */
    public static String TUIA_TIMESTAMP = "__tuia-timestamp__";

    /**
     * &tuiaDeleteKeys=signKey,zhangsan
     * callBack里面的不管
     */
    public static String TUIA_DELETE_KEYS = "tuiaDeleteKeys";

    /**
     * 定制化宏替换--------------------------------------------
     */
    public static String DEFAULT_OS = "3";
    public static String DEFAULT_OS_ANDRIOD = "android";
    public static String DEFAULT_OS_IOS = "ios";

    public static String BAIDU_OS = "__baidu_os__";

    public static String BAIDU_OS_KEY = "activity.call.black.baiduos";

    public static String VIPSHOP_OS = "__vipshop_os__";

    public static String VIPSHOP_OS_KEY = "activity.call.black.vipshopos";

}

==> tuia-public-tools-service-api-1.4.16-sources.jar: cn/tuia/tools/api/dto/advert/AdvertCallBackConstant.java <==
package cn.tuia.tools.api.dto.advert;

/**
 * @Description:
 * @author: 阿海
 * @create: 2020-06-28 17:40
 */
public class AdvertCallBackConstant {
    /**
     * 开关开启
     */
    public static String ON_FLAG = "1";

    /**
     * 宏替换开关，1为老版本，2为新版本，公共服务只有2才会处理
     */
    public static String MACRO_ON_FLAG_1 = "1";
    public static String MACRO_ON_FLAG_2 = "2";

    /**
     * 定制化处理--------------------------------------------------------------------------
     * 是否开启宏替换的开关
     */
    public static String MACRO_FLAG = "macro";

    /**
     * MD5签名处理，京东定制的需求
     * 参数上会拼接：&signMd5Flag=jingdong
     */
    public static String SIGN_MD5_FLAG = "signMd5Flag";

    /**
     * info日志开启的开关
     */
    public static String LOG_INFO_FLAG = "logInfoFlag";


    /**
     * 是否进行URL的decode开关
     * <p>
     * 【1】URLEncoder.encode(userAgent, "UTF-8")
     * ,ua.replaceAll("\\+","%20"))
     * <p>
     * 【2】大众点评：commonRestTemolate.getForObject(builder.build(true).toUri(), String.class);
     */
    public static String IS_ENCODE = "isEncode";

    /**
     * 宏替换的分隔符
     */
    public static String MACRO_SPLIT = "__";


    /**
     * 定制化处理宏替换--------------------------------------------
     */
    public static String TUIA_TIMESTAMP = "__tuia-timestamp__";
    /**
     * 毫秒的宏
     */
    public static String TUIA_MILLISECOND = "__tuia-tms__";

    /**
     * &tuiaDeleteKeys=signKey,zhangsan
     * callBack里面的不管
     */
    public static String TUIA_DELETE_KEYS = "tuiaDeleteKeys";

    /**
     * 定制化宏替换--------------------------------------------
     */
    public static String DEFAULT_OS = "3";
    public static String DEFAULT_OS_ANDRIOD = "android";
    public static String DEFAULT_OS_IOS = "ios";

    public static String BAIDU_OS = "__baidu_os__";

    public static String BAIDU_OS_KEY = "activity.call.black.baiduos";

    public static String VIPSHOP_OS = "__vipshop_os__";

    public static String VIPSHOP_OS_KEY = "activity.call.black.vipshopos";
    /**
     * tuia-os特殊处理
     */
    public static String TUIA_OS = "__tuia-os__";
    public static String OTHER = "other";

    public static String ELE_SALT_KEY = "ele.salt.key";


}
